OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "ຟາຍຖຶກອັບໂຫລດສຳເລັດ",
    "No file was uploaded" : "ບໍ່ມີການອັບໂຫລດຟາຍ",
    "Translate" : "ແປ",
    "Offline" : "ອັອບລາຍ",
    "Saving …" : "ກຳລັງບັນທຶກ",
    "Link" : "ລິງ",
    "Cancel" : "ຍົກເລີກ",
    "Replace" : "ປ່ຽນແທນ",
    "Edit" : "ແກ້ໄຂ",
    "Info" : "ຂໍ້ມຸນ",
    "Success" : "ຄວາມສໍາເລັດ",
    "Warning" : "ແຈ້ງເຕືອນ",
    "Details" : "ລາຍລະອຽດ"
},
"nplurals=1; plural=0;");
